Codegen Module
==============

.. module:: beluga.codegen

Introduction
------------

Base Class Reference
--------------------

.. autofunction:: make_control_and_ham_fn

.. autofunction:: make_functions

.. autofunction:: make_jit_fn

.. autofunction:: make_sympy_fn

.. autofunction:: preprocess
